==> easybpel.model.bpel.tools.validator-1.0-sources.jar: com/ebmwebsourcing/easybpel/model/bpel/tools/validator/BPELAnalyser.java <==
/**
 * easy BPEL software - Copyright (c) 2009 PetalsLink, 
 * http://www.petalslink.com/ 
 *  
 * This library is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU Lesser General Public License as published by the Free 
 * Software Foundation; either version 2.1 of the License, or (at your option) 
 * any later version. This library is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
 * General Public License for more details. 
 *  
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this library; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */
package com.ebmwebsourcing.easybpel.model.bpel.tools.validator;

import java.net.URL;

import org.ow2.easywsdl.extensions.wsdl4bpel.api.WSDL4BPELException;

import com.ebmwebsourcing.easybpel.model.bpel.BPELFactory;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELException;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELProcess;
import com.ebmwebsourcing.easybpel.model.bpel.api.inout.BPELReader;
import com.ebmwebsourcing.easybpel.model.bpel.tools.URLUtil;

public class BPELAnalyser {

	private static BPELReader reader = null;

	private static BPELException readerEx = null;

	static {
		try {
			reader = BPELFactory.newInstance().newBPELReader();
		} catch (final BPELException e) {
			readerEx = e;
		}

	}

	public static BPELReader getBPELReader() throws BPELException {
		if (readerEx != null) {
			throw readerEx;
		}
		return reader;
	}

	public BPELAnalyser() throws BPELException {
		BPELAnalyser.getBPELReader();
	}

	public AnalysorResult analyze(final URL bpel) throws BPELException {
		AnalysorResult res = null;
		if (bpel == null) {
			throw new BPELException("bpel uri cannot be null!!!");
		}
		try {
			BPELProcess process = null;
			process = BPELAnalyser.getBPELReader().readBPEL(URLUtil.urlToUri(bpel));
			res = new AnalysorResult(process);

		} catch (final WSDL4BPELException e) {
			throw new BPELException(e);
		}

		return res;
	}

}

==> easybpel.model.bpel.tools.validator-1.3-sources.jar: com/ebmwebsourcing/easybpel/model/bpel/tools/validator/BPELAnalyser.java <==
/**
 * easy BPEL software - Copyright (c) 2009 PetalsLink, 
 * http://www.petalslink.com/ 
 *  
 * This library is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU Lesser General Public License as published by the Free 
 * Software Foundation; either version 2.1 of the License, or (at your option) 
 * any later version. This library is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
 * General Public License for more details. 
 *  
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this library; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */
package com.ebmwebsourcing.easybpel.model.bpel.tools.validator;

import java.net.URL;

import org.ow2.easywsdl.extensions.wsdl4bpel.api.WSDL4BPELException;

import com.ebmwebsourcing.easybpel.model.bpel.api.BPELException;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELProcess;
import com.ebmwebsourcing.easybpel.model.bpel.api.inout.BPELReader;
import com.ebmwebsourcing.easybpel.model.bpel.impl.BPELFactoryImpl;
import com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.BPELStaticAnalysisImpl;
import com.ebmwebsourcing.easybpel.model.bpel.tools.URLUtil;

public class BPELAnalyser {

	private static BPELReader reader = null;

	private static BPELException readerEx = null;

	static {
		try {
			reader = BPELFactoryImpl.getInstance().newBPELReader();
		} catch (final BPELException e) {
			readerEx = e;
		}

	}

	public static BPELReader getBPELReader() throws BPELException {
		if (readerEx != null) {
			throw readerEx;
		}
		return reader;
	}

	public BPELAnalyser() throws BPELException {
		BPELAnalyser.getBPELReader();
	}

	public AnalysorResult analyze(final URL bpel) throws BPELException {
		AnalysorResult res = null;
		if (bpel == null) {
			throw new BPELException("bpel uri cannot be null!!!");
		}
		try {
			
			// clean static analysis
			BPELStaticAnalysisImpl.getInstance().getErrors().clear();
			BPELStaticAnalysisImpl.getInstance().getWarnings().clear();
			BPELStaticAnalysisImpl.getInstance().getInfos().clear();
			
			BPELProcess process = null;
			process = BPELAnalyser.getBPELReader().readBPEL(URLUtil.urlToUri(bpel));
			res = new AnalysorResult(process);

		} catch (final WSDL4BPELException e) {
			throw new BPELException(e);
		}

		return res;
	}

}
